@@ -3,7 +3,14 @@
 
 from datetime import datetime
 import warnings
-
+from email.mime.multipart import MIMEMultipart
+from email.utils import formataddr
+from email.mime.text import MIMEText
+import smtplib
+from email.mime.application import MIMEApplication
+import logging
+from email.mime.text import MIMEText
+import smtplib
 warnings.filterwarnings("ignore")  # 忽略警告
 
 
@@ -293,6 +300,33 @@ class ezfuc(object):
         if not os.path.exists(path):
             os.makedirs(path)
 
+    @staticmethod
+    def UUID(*arg):
+        import uuid
+        """
+        根据传过来的字符串进行"+"拼接后，进行uuid3加密
+        :param args:
+        :return:
+        """
+        line = ''.join(list(map(lambda x: str(x), arg)))
+        uuid_str = uuid.uuid3(uuid.NAMESPACE_DNS, line)
+        return str(uuid_str)
+
+    @staticmethod
+    def color_print(*arg, color="yellow"):
+        color_code = 33
+        if color.lower() == "red":
+            color_code = 31
+        if color.lower() == "green":
+            color_code = 32
+        if color.lower() == "blue":
+            color_code = 34
+        if color.lower() == "purple":
+            color_code = 35
+
+        st = ' '.join(list(map(lambda x: str(x), arg)))
+        print(f'\033[1;{color_code}m{st}\033[0m')
+
     @staticmethod
     def save_excel(resList, excel_name, title=None, path=""):
         """
@@ -305,7 +339,7 @@ class ezfuc(object):
         """
         import xlsxwriter
         from tqdm import tqdm
-        
+
         file_name = f"{excel_name}.xlsx"
         if path:
             ezfuc.make_dir(path=path)
@@ -387,19 +421,14 @@ class format_time(object):
 class EmailSend(object):
 
     def __init__(self, email_host, email_port, email_pass):
-        import logging
-
         self.logging = logging.getLogger('Waring')
         self.__email_host = email_host
         self.__email_port = email_port
         self.__email_pass = email_pass
 
     def send_text_email(self, to_address, content, from_addr='email', subject='title'):
-        from email.mime.text import MIMEText
-        import smtplib
-
         message_text = MIMEText(content, 'plain', 'utf8')
-        message_text['From'] = from_addr
+        message_text['From'] = formataddr(["筑龙爬虫部", from_addr])
         message_text['To'] = to_address
         message_text['Subject'] = subject
 
@@ -417,8 +446,28 @@ class EmailSend(object):
             # print('连接邮箱服务器异常：',e)
             self.logging.error('连接邮箱服务器异常：{}'.format(e))
 
-    def send_image_email(self):
-        pass
+    def send_xlsx_email(self, to_address,  from_addr='email', subject='title', file_name=""):
+        msg = MIMEMultipart()
+        msg['From'] = formataddr(["筑龙爬虫部", from_addr])
+        msg['To'] = to_address
+        msg['Subject'] = subject
+        xlsxpart = MIMEApplication(open(file_name, 'rb').read())
+        xlsxpart.add_header('Content-Disposition', 'attachment',
+                            filename=('gbk', '', file_name))
+        msg.attach(xlsxpart)
+        try:
+            client = smtplib.SMTP_SSL(self.__email_host, self.__email_port)
+            login_result = client.login(from_addr, self.__email_pass)
+            if login_result and login_result[0] == 235:
+                print('登录成功')
+                client.sendmail(from_addr, to_address, msg.as_string())
+                print('邮件发送成功')
+            else:
+                print('邮件发送异常：', login_result[0], login_result[1])
+        except Exception as e:
+            self.logging.error('连接邮箱服务器异常：{}'.format(e))
+
+
 
     def send_word_email(self):
         pass
